function ConvertFiles(directory)
%ConvertFiles(directory) Data file generating function
%   Kevin Mackie, 2001/03/03
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: directory - contains files to be converted
%					   note, you need to create a new directory beforehand
%					   with the name directory.mat
%
% This routine should be run before attempting to run the PSDM or IDA
% plotting utility.  It adds the data to .mat binary files to make
% plotting faster.

s=pwd;
cd(directory);
wd=cd;
newdir=sprintf('%s.mat',wd);
cd(s);
filelist=dir(wd);

for k=1:size(filelist),
   if filelist(k).isdir==0,
      file=fullfile(directory,filelist(k).name);
	  
	  GndFile = fopen(file, 'r');
      if ( GndFile == -1 ) 
         errm=sprintf('Cannot open file %s\n',file);
	     disp(errm);
         return;
      end

      points=0;
      buf = fgets(GndFile);
      while ( buf ~= -1) 
         if ( buf(1) ~= '%' ) 
            points=points+1;
	     end;
		 buf = fgets(GndFile);
	  end;
	  frewind(GndFile);
	
	  filedata=zeros(points,2);      % initialize data array, currently 2 columns max (T1,T2)
	  
      points=0;
      buf = fgets(GndFile);
      while ( buf ~= -1) 
         if ( buf(1) ~= '%' ) 
            points=points+1;

            outp=0;
            [loc,remd] = strtok(buf);
            while (outp==0) 
               if isempty(findstr('0123456789-',loc(1)))==0
                  outp=1;
                  filedata(points,1)=str2num(loc);
               else 
                  [loc,remd] = strtok(remd);
               end
            end;
			
			if length(remd) > 2
			   [loc,remd] = strtok(remd);
			   if isempty(findstr('0123456789-',loc(1)))==0
   			      filedata(points,2)=str2num(loc);
			   else
			      % for backwards compatibility for old pathological output files
			      filedata(points,2)=str2num(remd);
			   end;
			end;
         else 
            % comments line encountered
         end;
	     buf = fgets(GndFile);
      end;

      fclose(GndFile);
	  file=strtok(filelist(k).name,'.');
	  
	  cd(newdir);
	  save(file,'filedata');
	  cd(s);
	  
	  msg=sprintf('Done converting file %s',filelist(k).name);
	  disp(msg);
   end;
end;

cd(s);
